"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MinPriorityQueue = void 0;
const priority_queue_1 = require("./priority-queue");
class MinPriorityQueue extends priority_queue_1.PriorityQueue {
    /**
     * The constructor initializes a PriorityQueue with optional elements and options, including a
     * comparator function.
     * @param elements - The `elements` parameter is an iterable object that contains the initial
     * elements to be added to the priority queue. It is optional and defaults to an empty array if not
     * provided.
     * @param options - The `options` parameter is an object that contains additional configuration
     * options for the priority queue. In this case, it has a property called `comparator` which is a
     * function used to compare elements in the priority queue. The `comparator` function takes two
     * parameters `a` and `b`,
     */
    constructor(elements = [], options = {
        comparator: (a, b) => {
            if (!(typeof a === 'number' && typeof b === 'number')) {
                throw new Error('The a, b params of compare function must be number');
            }
            else {
                return a - b;
            }
        }
    }) {
        super(elements, options);
    }
}
exports.MinPriorityQueue = MinPriorityQueue;
